AWDLActionFrame

Struct AWDLActionFrame 

pub struct AWDLActionFrame<I> {
    pub subtype: AWDLActionFrameSubType,
    pub phy_tx_time: Duration,
    pub target_tx_time: Duration,
    pub tagged_data: I,
}
An AWDL AF(Action Frame).

Fields

subtype: AWDLActionFrameSubType

This is the subtype of the AF. Options are MIF and PSF.

phy_tx_time: Duration

The time the NIC physically started sending the frame, in μs.

target_tx_time: Duration

The time the driver send the frame to the NIC, in μs.

tagged_data: I

The TLVs contained in the action frame.

Implementations

Source

impl<I> AWDLActionFrame<I>

pub fn tx_delta(&self) -> Duration

Calculate the time, between the driver sending the frame to the WNIC and the transmission starting.