SyncTreeTLV

Struct SyncTreeTLV 

pub struct SyncTreeTLV<I> {
    pub tree: I,
}
This describes the structure of the AWDL mesh. The contained mac address are in descending order, with the first one being the mesh master and the other ones being sync masters.

Fields

tree: I

The MACs.